@@ -3,8 +3,8 @@
     authentication data.
                              -------------------
     begin                : Sa Feb 28 2004
-    copyright            : (C) 2004-2009 by Alexander Reinholdt
-    email                : dustpuppy@users.berlios.de
+    copyright            : (C) 2004-2011 by Alexander Reinholdt
+    email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -20,8 +20,8 @@
  *                                                                         *
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,   *
- *   MA  02111-1307 USA                                                    *
+ *   Free Software Foundation, Inc., 51 Franklin Street, Suite 500,        *
+ *   Boston, MA 02110-1335, USA                                            *
  ***************************************************************************/
 
 #ifndef SMB4KAUTHINFO_H
@@ -29,7 +29,6 @@
 
 // Qt includes
 #include <QString>
-#include <QByteArray>
 #include <QUrl>
 
 // KDE includes
@@ -68,6 +67,9 @@ class KDE_EXPORT Smb4KAuthInfo
 
     /**
      * Constructor for a share item.
+     * 
+     * In case the share is a 'homes' share, this constructor will automatically
+     * use the Smb4KShare::homeUNC() function to set the UNC.
      *
      * @param share     The Smb4KShare item.
      */
@@ -101,6 +103,9 @@ class KDE_EXPORT Smb4KAuthInfo
     /**
      * Set the share item. This overwrites all previous data that this object
      * might have carried including the password.
+     * 
+     * In case the share is a 'homes' share, this function will automatically
+     * use the Smb4KShare::homeUNC() function to set the UNC.
      *
      * @param share     The Smb4KShare item
      */
@@ -122,20 +127,6 @@ class KDE_EXPORT Smb4KAuthInfo
      */
     const QString &workgroupName() const { return m_workgroup; }
 
-    /**
-     * Sets the UNC of this item. It has to conform to the following scheme:
-     * [smb:]//[USER@]HOST[:PORT]/SHARE.
-     *
-     * The UNC may contain the protocol, i.e. "smb://". If a wrong protocol or a mal-
-     * formatted UNC is passed, this function will return immediately without doing
-     * anything.
-     *
-     * This function should only be used if you neither can use setHost() nor setShare().
-     *
-     * @param unc       The UNC of the item
-     */
-    void setUNC( const QString &unc );
-
     /**
      * Returns the UNC in the form [smb:]//[USER:PASSWORD@]HOST/SHARE depending on
      * the format specified by @p options.
@@ -172,6 +163,9 @@ class KDE_EXPORT Smb4KAuthInfo
 
     /**
      * Sets the login.
+     * 
+     * In case of a 'homes' share, this function will also set the share
+     * name to @p login.
      *
      * @param login     The login for the server/share
      */
@@ -182,7 +176,7 @@ class KDE_EXPORT Smb4KAuthInfo
      *
      * @returns         The login
      */
-    QByteArray login() const { return m_url.userName().toUtf8(); } // Do not use encodedUserName()
+    QString login() const { return m_url.userName(); }
 
     /**
      * Sets the password.
@@ -194,7 +188,7 @@ class KDE_EXPORT Smb4KAuthInfo
     /**
      * Returns the password.
      */
-    QByteArray password() const { return m_url.password().toUtf8(); } // Do not use encodedPassword()
+    QString password() const { return m_url.password(); }
 
     /**
      * Returns the type.
@@ -211,39 +205,55 @@ class KDE_EXPORT Smb4KAuthInfo
      */
     bool isHomesShare() const { return m_homes_share; }
 
-    /**
-     * This function is needed to change a 'homes' share to a 'user' share.
-     * It does only something if this item is of type 'Share' and is a
-     * 'homes' share.
-     *
-     * @param user      The user name that is replacing the 'homes' string
-     */
-    void setHomesUser( const QString &user );
-
     /**
      * This function sets the type of this authentication information to
      * "Default", i.e. it carries the default authentication information.
      */
-    void setDefaultAuthInfo();
+    void useDefaultAuthInfo();
 
     /**
-     * Set the list of defined users in case this is a homes share.
+     * Compare another Smb4KAuthInfo object with this one an return TRUE if both carry
+     * the same data.
      *
-     * Note that this function will only set the list if this indead is a
-     * homes share. It will just return otherwise.
+     * @param info            The Smb4KAuthInfo object that should be compared with this
+     *                        one.
      *
-     * @param users           The list of defined 'homes' share users.
+     * @returns TRUE if the data that was compared is the same.
      */
-    void setHomesUsers( const QStringList &users );
+    bool equals( Smb4KAuthInfo *info ) const;
+    
+    /**
+     * Operator to check if two authentication informations are equal.
+     */
+    bool operator==( Smb4KAuthInfo info ) { return equals( &info ); }
 
     /**
-     * Return the list of users that were defined for a homes share. If this
-     * authentication information represents a host or a share, that is not a
-     * 'homes' share, an empty list will be returned.
+     * Sets the URL of the share after some checks are passed.
      *
-     * @returns a list of users for a homes share.
+     * @param url             The URL of the network item
      */
-    const QStringList &homesUsers() const { return m_homes_users; }
+    void setURL( const QUrl &url );
+
+    /**
+     * Returns the URL of the network item
+     *
+     * @returns the URL
+     */
+    const QUrl &url() const { return m_url; }
+
+    /**
+     * Sets the IP address for this authentication information object
+     *
+     * @param ip          The IP address
+     */
+    void setIP( const QString &ip );
+
+    /**
+     * Returns the IP address
+     *
+     * @returns the IP address
+     */
+    const QString &ip() const { return m_ip; }
 
   private:
     /**
@@ -267,9 +277,21 @@ class KDE_EXPORT Smb4KAuthInfo
     bool m_homes_share;
 
     /**
-     * List of users defined for a homes share.
+     * The IP address
      */
-    QStringList m_homes_users;
+    QString m_ip;
+
+    /**
+     * This function checks if the given IP address is either
+     * compatible with IPv4 or IPv6. If it is not, an empty string
+     * is returned.
+     *
+     * @param ip              The IP address that needs to be checked.
+     *
+     * @returns the IP address or an empty string if the IP address
+     * is not compatible with either IPv4 or IPv6.
+     */
+    const QString &ipIsValid( const QString &ip );
 };
 
 #endif
