@@ -31,6 +31,7 @@
 #include <QDesktopWidget>
 #include <QTimer>
 #include <QFileInfo>
+#include <QTest>
 
 // KDE includes
 #include <kapplication.h>
@@ -84,6 +85,7 @@ Smb4KMounter::Smb4KMounter() : KCompositeJob( 0 )
   m_timeout = 0;
   m_checks = 0;
   m_dialog = NULL;
+  m_first_import_done = false;
 
   connect( kapp,                        SIGNAL( aboutToQuit() ),
            this,                        SLOT( slotAboutToQuit() ) );
@@ -279,6 +281,8 @@ void Smb4KMounter::triggerRemounts()
   {
     // Do nothing
   }
+  
+  m_remounting_done = true;
 }
 
 
@@ -1031,7 +1035,14 @@ void Smb4KMounter::unmountShares( const QList<Smb4KShare *> &shares, bool silent
           }
           else
           {
-            // Do nothing
+	    if ( p->aboutToQuit() )
+	    {
+	      continue;
+	    }
+	    else
+	    {
+	      // Do nothing
+	    }
           }
         }
       }
@@ -1085,13 +1096,27 @@ void Smb4KMounter::unmountShares( const QList<Smb4KShare *> &shares, bool silent
   
   addSubjob( job );
 
-  job->start();  
+  if ( !p->aboutToQuit() )
+  {
+    job->start();
+  }
+  else
+  {
+    job->synchronousStart();
+  }
 }
 
 
 void Smb4KMounter::unmountAllShares( QWidget *parent )
 {
-  unmountShares( mountedSharesList(), false, parent );
+  if ( !p->aboutToQuit() )
+  {
+    unmountShares( mountedSharesList(), false, parent );
+  }
+  else
+  {
+    unmountShares( mountedSharesList(), true, parent );
+  }
 }
 
 
@@ -1255,7 +1280,16 @@ void Smb4KMounter::timerEvent( QTimerEvent * )
     }
     
     // Clean up the mount prefix
-    cleanup();    
+    cleanup();
+
+    if ( Smb4KSettings::remountShares() && m_first_import_done && !m_remounting_done )
+    {
+      triggerRemounts();
+    }
+    else
+    {
+      // Do nothing
+    }
   }
   else
   {
@@ -1273,20 +1307,19 @@ void Smb4KMounter::timerEvent( QTimerEvent * )
 
 void Smb4KMounter::slotStartJobs()
 {
-  startTimer( TIMEOUT );
-
   import( true );
 
   if ( Smb4KSolidInterface::self()->networkStatus() == Smb4KSolidInterface::Connected ||
        Smb4KSolidInterface::self()->networkStatus() == Smb4KSolidInterface::Unknown )
   {
     p->setHardwareReason( false );
-    triggerRemounts();
   }
   else
   {
     // Do nothing and wait until the network becomes available.
   }
+
+  startTimer( TIMEOUT );
 }
 
 
@@ -1305,6 +1338,12 @@ void Smb4KMounter::slotAboutToQuit()
   if ( Smb4KSettings::unmountSharesOnExit() )
   {
     unmountAllShares();
+    
+    // Wait until done.
+    while ( hasSubjobs() )
+    {
+      QTest::qWait( TIMEOUT );
+    }
   }
   else
   {
@@ -2005,6 +2044,15 @@ void Smb4KMounter::slotStatResult( KJob *job )
       // Do nothing
     }
   }
+  
+  if ( !m_first_import_done && m_imported_shares.isEmpty() )
+  {
+    m_first_import_done = true;
+  }
+  else
+  {
+    // Do nothing
+  }
 }
 
 
