@@ -138,6 +138,26 @@ bool Smb4KMountJob::createMountAction( Smb4KShare *share, Action *action )
     // Do nothing
   }
 
+  // Get the permissions that should be used for creating the
+  // mount prefix and all its subdirectories. 
+  // Please note that the actual permissions of the mount points
+  // are determined by the mount utility.
+  QFile::Permissions permissions;
+  KUrl parentDirectory;
+  
+  if ( QFile::exists( Smb4KSettings::mountPrefix().path() ) )
+  {
+    parentDirectory = Smb4KSettings::mountPrefix();
+  }
+  else
+  {
+    KUrl u( Smb4KSettings::mountPrefix() );
+    parentDirectory = u.upUrl();
+  }
+  
+  QFile f( parentDirectory.path() );
+  permissions = f.permissions();
+  
   // Assemble the mount point and create it.
   QString mountpoint;
   mountpoint += Smb4KSettings::mountPrefix().path();
@@ -164,6 +184,14 @@ bool Smb4KMountJob::createMountAction( Smb4KShare *share, Action *action )
   }
   else
   {
+    KUrl u( dir.path() );
+    
+    while ( !parentDirectory.equals( u, KUrl::CompareWithoutTrailingSlash ) )
+    {
+      QFile( u.path() ).setPermissions( permissions );
+      u = u.upUrl();
+    }
+    
     share->setPath( dir.path() );
   }
 
@@ -729,14 +757,13 @@ void Smb4KMountJob::slotActionFinished( ActionReply reply )
       // Check if the mount process reported an error
       QString stderr( reply.data()["stderr"].toString() );
 
-      if ( share->canonicalPath() == reply.data()["share_mountpoint"].toByteArray() && !stderr.isEmpty() )
+      if ( QString::compare( share->canonicalPath(), reply.data()["share_mountpoint"].toString() ) == 0 && !stderr.isEmpty() )
       {
 #ifndef Q_OS_FREEBSD
         if ( stderr.contains( "mount error 13", Qt::CaseSensitive ) || stderr.contains( "mount error(13)" )
             /* authentication error */ )
         {
-          m_auth_errors << *share;
-          emit authError( this );
+          m_auth_errors << Smb4KShare( *share );
         }
         else if ( (stderr.contains( "mount error 6" ) || stderr.contains( "mount error(6)" )) /* bad share name */ &&
                   share->shareName().contains( "_", Qt::CaseSensitive ) )
@@ -744,7 +771,6 @@ void Smb4KMountJob::slotActionFinished( ActionReply reply )
           QString share_name = share->shareName();
           share->setShareName( share_name.replace( "_", " " ) );
           m_retries << *share;
-          emit retry( this );
         }
         else if ( stderr.contains( "mount error 101" ) || stderr.contains( "mount error(101)" ) /* network unreachable */ )
         {
@@ -754,7 +780,6 @@ void Smb4KMountJob::slotActionFinished( ActionReply reply )
         if ( stderr.contains( "Authentication error" ) )
         {
           m_auth_errors << *share;
-          emit authError( this );
         }
 #endif
         else
@@ -786,6 +811,24 @@ void Smb4KMountJob::slotActionFinished( ActionReply reply )
 
   if ( m_processed == m_shares.size() )
   {
+    if ( !m_auth_errors.isEmpty() )
+    {
+      emit authError( this );
+    }
+    else
+    {
+      // Do nothing
+    }
+
+    if ( !m_retries.isEmpty() )
+    {
+      emit retry( this );
+    }
+    else
+    {
+      // Do nothing
+    }
+	  
     // Give the operating system some time to process the mounts
     // before we invoke KMountPoint::currentMountPoints().
     QTimer::singleShot( 100, this, SLOT( slotFinishJob() ) );
@@ -854,6 +897,13 @@ void Smb4KUnmountJob::start()
 }
 
 
+void Smb4KUnmountJob::synchronousStart()
+{
+  m_started = true;
+  slotStartUnmount();
+}
+
+
 void Smb4KUnmountJob::setupUnmount( Smb4KShare *share, bool force, bool silent, QWidget *parent )
 {
   Q_ASSERT( share );
@@ -1013,20 +1063,10 @@ void Smb4KUnmountJob::slotActionFinished( ActionReply reply )
       // Check if the unmount process reported an error
       QString stderr( reply.data()["stderr"].toString() );
 
-      if ( share->canonicalPath() == reply.data()["share_mountpoint"].toByteArray() && !stderr.isEmpty() )
+      if ( QString::compare( share->canonicalPath(), reply.data()["share_mountpoint"].toString() ) == 0 && !stderr.isEmpty() )
       {
-        // Check if an error occurred.
-        QString stderr( reply.data().value( "stderr" ).toString() );
-
-        if ( !stderr.isEmpty() )
-        {
-          Smb4KNotification *notification = new Smb4KNotification();
-          notification->unmountingFailed( share, stderr );
-        }
-        else
-        {
-          // Do nothing
-        }
+        Smb4KNotification *notification = new Smb4KNotification();
+        notification->unmountingFailed( share, stderr );
       }
       else
       {
