@@ -2,8 +2,8 @@
     smb4kshare  -  Smb4K's container class for information about a share.
                              -------------------
     begin                : Mo Jan 28 2008
-    copyright            : (C) 2008 by Alexander Reinholdt
-    email                : dustpuppy@users.berlios.de
+    copyright            : (C) 2008-2011 by Alexander Reinholdt
+    email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -19,8 +19,8 @@
  *                                                                         *
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,   *
- *   MA  02111-1307 USA                                                    *
+ *   Free Software Foundation, 51 Franklin Street, Suite 500, Boston,      *
+ *   MA 02110-1335, USA                                                    *
  ***************************************************************************/
 
 #ifndef SMB4KSHARE_H
@@ -32,14 +32,21 @@
 
 // Qt includes
 #include <QString>
-#include <QByteArray>
 #include <QStringList>
+#include <QtGlobal>
+#include <QUrl>
 
 // KDE includes
 #include <kuser.h>
 #include <kdemacros.h>
 
-class KDE_EXPORT Smb4KShare
+// application specific includes
+#include <smb4kbasicnetworkitem.h>
+
+// forward declarations
+class Smb4KAuthInfo;
+
+class KDE_EXPORT Smb4KShare : public Smb4KBasicNetworkItem
 {
   public:
     /**
@@ -58,12 +65,12 @@ class KDE_EXPORT Smb4KShare
                 const QString &name );
 
     /**
-     * This constructor takes the UNC @p unc (in the form //[USER@]HOST/SHARE) as
-     * only argument. It decodes the host and the share name from the UNC, so
-     * host() and name() will immediately return the correct values. All other
-     * information has to be set by the other functions this class provides.
+     * This constructor takes the UNC @p unc (in the form [smb:]//[USER@]HOST/SHARE) as
+     * only argument. It feeds the internal QUrl object with the string, that extracts
+     * all parts from it. All other information has to be set by the other functions
+     * this class provides.
      *
-     * @param unc           The UNC in the form //[USER@]HOST/SHARE.
+     * @param unc           The UNC in the form [smb:]//[USER@]HOST/SHARE.
      */
     Smb4KShare( const QString &unc );
 
@@ -91,50 +98,104 @@ class KDE_EXPORT Smb4KShare
      *
      * @param name          The share name
      */
-    void setName( const QString &name );
+    void setShareName( const QString &name );
 
     /**
      * Returns the name of the share, e.g. "Music", "Data", etc.
      *
      * @returns the name of the share.
      */
-    const QString &name() const { return m_name; }
+    QString shareName() const;
 
     /**
      * Sets the name of the host where the share is located.
      *
      * @param hostName      The host name
      */
-    void setHost( const QString &hostName );
+    void setHostName( const QString &hostName );
 
     /**
      * Returns the name of the host where the share is located.
      *
      * @returns the host name
      */
-    const QString &host() const { return m_host; }
+    QString hostName() const { return m_url.host().toUpper(); }
 
     /**
-     * This function sets the UNC (Uniform Naming Convention string). This
-     * has to conform to the following scheme: //[USER@]HOST/SHARE.
-     *
-     * @param unc           The UNC of the share
-     */
-    void setUNC( const QString &unc );
-
-    /**
-     * Returns the UNC in the form //[USER@]HOST/SHARE.
+     * Returns the UNC (Uniform Naming Convention string) address in the form 
+     * [smb:]//[USER:PASS@]HOST[:PORT]/SHARE depending on the format specified by 
+     * @p options.
+     * 
+     * Please note that this function returns a modified URL string (uppercase
+     * hostname, etc.) and automatically strips a trailing slash if one is present.
      *
      * @returns the UNC.
      */
-    const QString &unc() const { return m_unc; }
+    QString unc( QUrl::FormattingOptions options = QUrl::RemoveScheme|
+                                                   QUrl::RemoveUserInfo|
+                                                   QUrl::RemovePort ) const;
+                                                   
+    /**
+     * In case of a 'homes' share, this function returns the UNC of the user's 
+     * home repository in the form [smb:]//[USER@]HOST[:PORT]/USER depending 
+     * on the format specified by @p options.
+     * 
+     * If the share is not a 'homes' share or no user name for the homes share
+     * has been defined, this function returns an empty string.
+     * 
+     * Please note that this function returns a modified URL string (uppercase
+     * hostname, etc.) and automatically strips a trailing slash if one is present.
+     *
+     * @returns the UNC.
+     */
+    QString homeUNC( QUrl::FormattingOptions options = QUrl::RemoveScheme|
+                                                       QUrl::RemoveUserInfo|
+                                                       QUrl::RemovePort ) const;
+                                                       
+    /**
+     * Sets the URL of the share after some checks are passed.
+     * 
+     * @param url             The URL of the network item
+     */
+    void setURL( const QUrl &url );
+    
+    /**
+     * Returns the URL of the share.
+     * 
+     * @returns the URL of the share.
+     */
+    const QUrl &url() const { return m_url; }
+                                                       
+    /**
+     * In case of a 'homes' share, this function returns the URL of the user's 
+     * home repository.
+     * 
+     * If the share is not a 'homes' share or no user name for the homes share
+     * has been defined, this function returns an empty string.
+     * 
+     * @returns the user's home repository's URL.
+     */
+    QUrl homeURL() const;
+
+    /**
+     * Returns the host's UNC in the form [smb:]//[USER@]HOST[:PORT] depending on
+     * the format specified by @p options.
+     * 
+     * Please note that this function returns a modified URL string (uppercase
+     * hostname) and automatically strips a trailing slash if one is present.
+     *
+     * @returns the UNC of the host.
+     */
+    QString hostUNC( QUrl::FormattingOptions options = QUrl::RemoveScheme|
+                                                       QUrl::RemoveUserInfo|
+                                                       QUrl::RemovePort ) const;
 
     /**
      * Set the workgroup where the host is located that offers this share.
      *
      * @param workgroup     The name of the workgroup
      */
-    void setWorkgroup( const QString &workgroup );
+    void setWorkgroupName( const QString &workgroup );
 
     /**
      * Returns the name of the workgroup where the host is located that
@@ -142,31 +203,31 @@ class KDE_EXPORT Smb4KShare
      *
      * @returns the workgroup name
      */
-    const QString &workgroup() const { return m_workgroup; }
+    const QString &workgroupName() const { return m_workgroup; }
 
     /**
-     * Sets the type of the share.
+     * Sets the type string (Disk, Print, IPC) of the share.
      *
      * @param type          The string defining the type of the share
      */
-    void setType( const QString &type );
+    void setTypeString( const QString &typeString );
 
     /**
-     * Returns the type of the share as reported by the server. If you are
-     * looking for a translated type string, then use the translatedType()
+     * Returns the type string of the share as reported by the server. If you are
+     * looking for a translated type string, then use the translatedTypeString()
      * function.
      *
      * @returns the type of the share.
      */
-    const QString &type() const { return m_type; }
+    const QString &typeString() const { return m_type_string; }
 
     /**
-     * Returns the type of the share as translated string. You can use this
+     * Returns the translated type string of the share. You can use this
      * in the GUI.
      *
      * @returns a translated type string.
      */
-    const QString translatedType() const;
+    const QString translatedTypeString() const;
 
     /**
      * Sets the comment that was defined for the share.
@@ -243,7 +304,7 @@ class KDE_EXPORT Smb4KShare
      *
      * @returns the path to the mounted share.
      */
-    const QByteArray &path() const { return m_path; }
+    const QString &path() const { return m_path; }
 
     /**
      * Returns the canonical path to the mounted share. In contrast to the path()
@@ -253,7 +314,7 @@ class KDE_EXPORT Smb4KShare
      *
      * @returns the canonical path to the mounted share.
      */
-    const QByteArray canonicalPath() const;
+    const QString canonicalPath() const;
 
     /**
      * Set @p in to TRUE if the share cannot be accessed by the user. This may be
@@ -340,14 +401,6 @@ class KDE_EXPORT Smb4KShare
      */
     const QString owner() const { return m_user.loginName(); }
 
-    /**
-     * Returns TRUE if the UID was set by invoking the setUID() function and
-     * FALSE otherwise.
-     *
-     * @returns TRUE if the UID was set.
-     */
-    bool uidIsSet() const { return m_uid_set; }
-
     /**
      * Set the owning GID of this share.
      *
@@ -372,138 +425,89 @@ class KDE_EXPORT Smb4KShare
     const QString group() const { return m_group.name(); }
 
     /**
-     * Returns TRUE if the GID was set by invoking the setGID() function and
-     * FALSE otherwise.
-     *
-     * @returns TRUE if the GID was set.
-     */
-    bool gidIsSet() const { return m_gid_set; }
-
-#ifndef __FreeBSD__
-    /**
-     * Sets the login that is used to mount a share with the CIFS file system
-     * (not available under FreeBSD).
-     *
-     * @param login           The CIFS login
-     */
-    void setCIFSLogin( const QString &login );
-
-    /**
-     * Returns the login that was used to mount a share with the CIFS file
-     * system (not available under FreeBSD). The default value is the local
-     * user name that is send when the user=USER option is not provided.
-     *
-     * @returns the CIFS login.
-     */
-    const QString &cifsLogin() const { return m_login; }
-
-    /**
-     * Returns TRUE if the CIFS login was set by invoking the setCIFSLogin() function and
-     * FALSE otherwise.
-     *
-     * @returns TRUE if the CIFS login was set.
-     */
-    bool cifsLoginIsSet() const { return m_login_set; }
-#else
-    /**
-     * Sets the login that is used to mount a share and inevitably also the
-     * UNC (FreeBSD only).
-     *
-     * @param login           The login
-     */
-    void setLogin( const QString &login );
-
-    /**
-     * Returns the login that was used to mount a share (FreeBSD only).
-     *
-     * @returns the login.
-     */
-    const QString &login() const { return m_login; }
-
-    /**
-     * Returns TRUE if the login was set by invoking the setLogin() function and
-     * FALSE otherwise.
-     *
-     * @returns TRUE if the login was set.
-     */
-    bool loginIsSet() const { return m_login_set; }
-#endif
-
-    /**
-     * Sets the value of the total disk space that is available on the share. The
-     * value has to be provided in KiloBytes. If the disk usage could not be
-     * determined, @p total has to be set to -1.
+     * Sets the value of the total disk space that is available on the share. If 
+     * the disk usage could not be determined, @p size has to be set to 0.
      *
      * @param total           The total disk space that is available on the share
      */
-    void setTotalDiskSpace( double total );
+    void setTotalDiskSpace( qulonglong size );
 
     /**
-     * Returns the total disk space that is available on the share or -1 if the
-     * disk space was not set or could not be determined.
+     * Returns the total disk space that is available on the share or 0 if the
+     * total disk space was not set or could not be determined.
      *
-     * @returns the total disk space or -1.
+     * @returns the total disk space or 0.
      */
-    double totalDiskSpace() const { return m_total; }
+    qulonglong totalDiskSpace() const { return m_total; }
 
     /**
-     * Returns the total disk space in a human readable form with value and unit,
-     * for example 10 KiB, 25 MiB, etc. If the total disk space was not set or
-     * could not be determined, this funtion returns an empty string.
+     * Returns the total disk space in a human readable form with value and unit
+     * (e.g. 10 KiB, 25 MiB, etc.) even if the total disk space was not set or could
+     * not be determined. If the value is a valid one, you have to check by evaluating
+     * the return value of the isInaccessible() function.
      *
-     * @returns the total disk space in a human readable form or an empty string.
+     * @returns the total disk space in a human readable form.
      */
     QString totalDiskSpaceString() const;
 
     /**
-     * Sets the value of the free disk space that is available on the share. The
-     * value has to be provided in KiloBytes. If the free disk space could not be
-     * determined, @p free has to be set to -1.
+     * Sets the value of the free disk space that is available on the share. If 
+     * the free disk space could not be determined, @p size has to be set to 0.
      *
      * @param free            The free disk space that is available on the share
      */
-    void setFreeDiskSpace( double free );
+    void setFreeDiskSpace( qulonglong size );
 
     /**
-     * Returns the free disk space that is available on the share or -1 if the disk
-     * space was not set or could not be determined.
+     * Returns the free disk space that is available on the share or 0 if the
+     * free disk space was not set or could not be determined.
      *
-     * @returns the free disk space or -1.
+     * @returns the free disk space or 0.
      */
-    double freeDiskSpace() const { return m_free; }
+    qulonglong freeDiskSpace() const { return m_free; }
 
     /**
-     * Returns the free disk space in a human readable form with value and unit,
-     * for example 10 KiB, 25 MiB, etc. If the free disk space was not set or
-     * could not be determined, this funtion returns an empty string.
+     * Returns the free disk space in a human readable form with value and unit
+     * (e.g. 10 KiB, 25 MiB, etc.) even if the free disk space was not set or could
+     * not be determined. If the value is a valid one, you have to check by evaluating
+     * the return value of the isInaccessible() function.
      *
-     * @returns the free disk space in a human readable form or an empty string.
+     * @returns the free disk space in a human readable form.
      */
     QString freeDiskSpaceString() const;
-
+    
     /**
-     * Returns the used disk space that is used on the share or -1 if it
-     * could not be determined.
+     * Sets the value of the disk space that is used on the share. If the used 
+     * disk space could not be determined, @p size has to be set to 0.
      *
-     * @returns the used disk space or -1.
+     * @param free            The free disk space that is available on the share
      */
-    double usedDiskSpace() const;
+    void setUsedDiskSpace( qulonglong size );
 
     /**
-     * Returns the used disk space in a human readable form with value and unit,
-     * for example 10 KiB, 25 MiB, etc. If the used disk space was not set or
-     * could not be determined, this funtion returns an empty string.
+     * Returns the used disk space that is used on the share or 0 if the
+     * used disk space was not set or could not be determined.
      *
-     * @returns the used disk space in a human readable form or an empty string.
+     * @returns the used disk space or 0.
+     */
+    qulonglong usedDiskSpace() const { return m_used; }
+
+    /**
+     * Returns the used disk space in a human readable form with value and unit
+     * (e.g. 10 KiB, 25 MiB, etc.) even if the used disk space was not set or could
+     * not be determined. If the value is a valid one, you have to check by evaluating
+     * the return value of the isInaccessible() function.
+     *
+     * @returns the used disk space in a human readable form.
      */
     QString usedDiskSpaceString() const;
 
     /**
-     * Returns the disk usage in percent or, if it could not be determined -1.
-     *
-     * @returns the disk usage in percent or -1.
+     * Returns the disk usage in percent.
+     
+     * @returns the disk usage in percent.
      */
-    double diskUsage() const;
+    qreal diskUsage() const;
 
     /**
      * Returns the disk usage in a human readable form with value and unit,
@@ -543,8 +547,13 @@ class KDE_EXPORT Smb4KShare
      *
      * @returns TRUE if the data that was compared is the same.
      */
-    bool equals( const Smb4KShare &share,
+    bool equals( Smb4KShare *share,
                  CheckFlags flag );
+                 
+    /**
+     * Operator to check if two shares are equal. This operator performs a full check.
+     */
+    bool operator==( Smb4KShare share ) { return equals( &share, Full ); }
 
     /**
      * Returns TRUE if values that were checked according to @p flag are empty.
@@ -596,41 +605,78 @@ class KDE_EXPORT Smb4KShare
      *
      * @returns TRUE if this is or *was* a 'homes' share and FALSE otherwise.
      */
-    bool isHomesShare() const { return m_homes_share; }
+    bool isHomesShare() const;
 
     /**
-     * Set the list of defined users in case this is a homes share.
+     * Set the port for the use in the UNC.
      *
-     * Note that this function will only set the list if this indead is a
-     * homes share. It will just return otherwise.
-     *
-     * @param users           The list of defined 'homes' share users.
+     * @param port            The port
      */
-    void setHomesUsers( const QStringList &users );
+    void setPort( int port );
 
     /**
-     * Returns the list of defined 'homes' share users or an empty list.
+     * Returns the port that is used in the UNC.
      *
-     * @returns the list of 'homes' share users.
+     * @returns the port.
      */
-    const QStringList &homesUsers() const { return m_homes_users; }
+    int port() const { return m_url.port(); }
+
+    /**
+     * Set the authentication information for the share. This function will add
+     * the authentication information to the URL of the share. Any previous
+     * user information including the login will be overwritten.
+     *
+     * @param authInfo    The authentication information
+     */
+    void setAuthInfo( Smb4KAuthInfo *authInfo );
+    
+    /**
+     * Set the login for the share. This function will add the login name
+     * to the URL of the share.
+     * 
+     * @param login       The login name
+     */
+    void setLogin( const QString &login );
+    
+    /**
+     * Returns the login.
+     *
+     * @returns the login.
+     */
+    QString login() const { return m_url.userName(); }
+    
+    /**
+     * Set the password used for authentication.
+     * 
+     * @param passwd              The password
+     */
+    void setPassword( const QString &passwd );
+    
+    /**
+     * Returns the password.
+     * 
+     * @returns the password.
+     */
+    QString password() const { return m_url.password(); }
+    
+    /**
+     * Returns TRUE if the host's IP address is set and FALSE otherwise.
+     * 
+     * @returns TRUE if the host's IP address is set and FALSE otherwise.
+     */
+    bool hasHostIP() const { return !m_host_ip.isEmpty(); }
 
   private:
     /**
-     * The share's name.
+     * The URL
      */
-    QString m_name;
-
+    QUrl m_url;
+    
     /**
-     * The host
+     * Set up the shares icon.
      */
-    QString m_host;
-
-    /**
-     * The UNC (Uniforn Naming Convention) string
-     */
-    QString m_unc;
-
+    void setShareIcon();
+    
     /**
      * The workgroup
      */
@@ -639,7 +685,7 @@ class KDE_EXPORT Smb4KShare
     /**
      * The type of the share
      */
-    QString m_type;
+    QString m_type_string;
 
     /**
      * The comment
@@ -654,7 +700,7 @@ class KDE_EXPORT Smb4KShare
     /**
      * The path to the mounted share
      */
-    QByteArray m_path;
+    QString m_path;
 
     /**
      * Determines if the share is inaccessible
@@ -681,51 +727,26 @@ class KDE_EXPORT Smb4KShare
      */
     KUserGroup m_group;
 
-    /**
-     * The (CIFS) login
-     */
-    QString m_login;
-
     /**
      * The total disk space
      */
-    double m_total;
+    qulonglong m_total;
 
     /**
      * The free disk space
      */
-    double m_free;
-
+    qulonglong m_free;
+    
     /**
-     * UID was set
+     * The used disk space
      */
-    bool m_uid_set;
-
-    /**
-     * GID was set
-     */
-    bool m_gid_set;
-
-    /**
-     * Login was set
-     */
-    bool m_login_set;
+    qulonglong m_used;
 
     /**
      * Is mounted
      */
     bool m_is_mounted;
 
-    /**
-     * 'homes' share?
-     */
-    bool m_homes_share;
-
-    /**
-     * The list of 'homes' users
-     */
-    QStringList m_homes_users;
-
     /**
      * This function checks if the given IP address is either
      * compatible with IPv4 or IPv6. If it is not, an empty string
