@@ -3,8 +3,8 @@
     browser of Smb4K.
                              -------------------
     begin                : Fr Jan 5 2007
-    copyright            : (C) 2007-2008 by Alexander Reinholdt
-    email                : dustpuppy@users.berlios.de
+    copyright            : (C) 2007-2011 by Alexander Reinholdt
+    email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -47,6 +47,7 @@ class Smb4KNetworkBrowserItem;
 class Smb4KWorkgroup;
 class Smb4KHost;
 class Smb4KShare;
+class Smb4KBasicNetworkItem;
 
 /**
  * This is one of the parts of Smb4K. It contains the network browser.
@@ -68,11 +69,12 @@ class Smb4KNetworkBrowserPart : public KParts::Part
      *
      * @param args                A list of arguments. At the moment the following
      *                            arguments are recognized:
-     *                            konqplugin="true"|"false"
+     *                            bookmark_shortcut="true"|"false"
+     *                            silent="true"|"false"
      */
     Smb4KNetworkBrowserPart( QWidget *parentWidget = 0,
                              QObject *parent = 0,
-                             const QStringList &args = QStringList() );
+                             const QList<QVariant> &args = QList<QVariant>() );
 
     /**
      * The destructor.
@@ -124,21 +126,6 @@ class Smb4KNetworkBrowserPart : public KParts::Part
     void slotItemPressed( QTreeWidgetItem *item,
                           int column );
 
-    /**
-     * This slot is called when an item has been expanded. It is used to
-     * invoke the functions of the scanner that need to be run.
-     *
-     * @param item                The item that has been expanded.
-     */
-    void slotItemExpanded( QTreeWidgetItem *item );
-
-    /**
-     * This slot is called when an item has been collapsed.
-     *
-     * @param item                The item that has been collapsed.
-     */
-    void slotItemCollapsed( QTreeWidgetItem *item );
-
     /**
      * This slot is invoked when the user executed an item. It is used to mount
      * shares.
@@ -156,16 +143,19 @@ class Smb4KNetworkBrowserPart : public KParts::Part
      * actions that have to be taken by the scanner to complete the information
      * on the network items shown in the browser.
      *
-     * @param item                The item for which the additional info should
+     * @param item                The item for which the additional info is to
      *                            be retrieved
      */
-    void slotAboutToShowToolTip( Smb4KNetworkBrowserItem *item );
+    void slotAboutToShowToolTip( Smb4KBasicNetworkItem *item );
 
     /**
      * This slot is called when the tool tip is about to be closed. It stops the
      * search for addtitional information if necessary.
+     * 
+     * @param item                The item for which the additional info was to
+     *                            be retrieved
      */
-    void slotAboutToHideToolTip();
+    void slotAboutToHideToolTip( Smb4KBasicNetworkItem *item );
 
     /**
      * This slot receives the workgroups/domains found by the scanner. It takes
@@ -180,14 +170,11 @@ class Smb4KNetworkBrowserPart : public KParts::Part
     /**
      * This slot receives the list of workgroup/domain members that were found
      * by the scanner. It takes this @p list and inserts it into the list view.
-     * The parent of the items is the workgroup/domain item with the name
-     * @p workgroup. Obsolete items will be deleted from the network browser.
-     *
-     * @param workgroup           The workgroup where the hosts belong
+     * Obsolete items will be deleted from the network browser.
      *
      * @param list                A list of Smb4KHostItem objects
      */
-    void slotWorkgroupMembers( const QString &workgroup,
+    void slotWorkgroupMembers( Smb4KWorkgroup *workgroup,
                                const QList<Smb4KHost *> &list );
 
     /**
@@ -199,7 +186,7 @@ class Smb4KNetworkBrowserPart : public KParts::Part
      *
      * @param list                The list of shares that belong to @p host
      */
-    void slotShares( const QString &host,
+    void slotShares( Smb4KHost *host,
                      const QList<Smb4KShare *> &list );
 
     /**
@@ -218,16 +205,17 @@ class Smb4KNetworkBrowserPart : public KParts::Part
      * @param host                A Smb4KHost item with updated contents.
      */
     void slotAddInformation( Smb4KHost *host );
-
+    
     /**
-     * This slots is connected to the Smb4KScanner::hostAdded() signal and inserts
-     * a single host in the list view. If the host is already present, nothing is
-     * done.
-     *
-     * @param host                A Smb4KHost item that is to be added to the
-     *                            tree widget.
+     * This slot is called when an authentication error occurred. Depending on
+     * the @p process parameter it will take respective actions.
+     * 
+     * @param host                The host where the authentication error occurred
+     * 
+     * @param process             The process (action) that was running while the
+     *                            authentication error occurred
      */
-    void slotInsertHost( Smb4KHost *host );
+    void slotAuthError( Smb4KHost *host, int process );
 
     /**
      * Rescan the network. This slot is connected to the 'Rescan' action.
@@ -298,30 +286,73 @@ class Smb4KNetworkBrowserPart : public KParts::Part
     void slotMount( bool checked );
 
     /**
-     * Unmount a share. This slot is only relevant in the Konqueror plugin
-     * mode.
+     * This slot is connected to the Smb4KScanner::aboutToStart() signal.
      *
-     * @param checked             Is TRUE if the action is checked (not used here).
+     * @param item                The Smb4KBasicNetworkItem object
+     *
+     * @param process             The process
      */
-    void slotUnmount( bool checked );
+    void slotScannerAboutToStart( Smb4KBasicNetworkItem *item,
+                                  int process );
 
     /**
-     * This slot is invoked by the Smb4KMounter::updated() signal and changes
-     * the text and icon of all shares that are already mounted.
+     * This slot is connected to the Smb4KScanner::finished() signal.
+     *
+     * @param item                The Smb4KBasicNetworkItem object
+     *
+     * @param process             The process
      */
-    void slotMarkMountedShares();
+    void slotScannerFinished( Smb4KBasicNetworkItem *item,
+                              int process );
 
     /**
-     * This slot is connected to the Smb4KCore::runStateChanged() signal and
-     * is used to enable/disable actions.
+     * This slot is connected to the Smb4KMounter::aboutToStart() signal.
+     *
+     * @param share               The Smb4KShare object
+     *
+     * @param process             The process
      */
-    void slotRunStateChanged();
+    void slotMounterAboutToStart( Smb4KShare *share,
+                                  int process);
+
+    /**
+     * This slot is connected to the Smb4KMounter::finished() signal.
+     *
+     * @param share               The Smb4KShare object
+     *
+     * @param process             The process
+     */
+    void slotMounterFinished( Smb4KShare *share,
+                              int process );
+
+    /**
+     * This slot is called whenever a share has been mounted. It marks the
+     * respective share in the tree widget as mounted.
+     *
+     * @param share               The Smb4KShare object
+     */
+    void slotShareMounted( Smb4KShare *share );
+
+    /**
+     * This slot is called whenever a share has been unmounted. It marks the
+     * respective share in the tree widget as not mounted.
+     *
+     * @param share               The Smb4KShare object
+     */
+    void slotShareUnmounted( Smb4KShare *share );
 
     /**
      * This slot is invoked shortly before the application quits. It is used
      * to save widget related settings.
      */
     void slotAboutToQuit();
+    
+    /**
+     * This slot is called if the icon size was changed.
+     *
+     * @param group               The icon group
+     */
+    void slotIconSizeChanged( int group );
 
   private:
     /**
@@ -350,14 +381,14 @@ class Smb4KNetworkBrowserPart : public KParts::Part
     Smb4KNetworkBrowser *m_widget;
 
     /**
-     * The modus
+     * The bookmark action has got a shortcut
      */
-    enum Mode { Normal, KonqPlugin };
-
+    bool m_bookmark_shortcut;
+    
     /**
-     * The list of arguments
+     * Emit status messages
      */
-    Mode m_mode;
+    bool m_silent;
 
     /**
      * The menu title
