@@ -3,8 +3,8 @@
     Samba settings of Smb4K
                              -------------------
     begin                : Mo Jan 26 2004
-    copyright            : (C) 2004-2008 by Alexander Reinholdt
-    email                : dustpuppy@users.berlios.de
+    copyright            : (C) 2004-2011 by Alexander Reinholdt
+    email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -20,8 +20,8 @@
  *                                                                         *
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,   *
- *   MA  02111-1307 USA                                                    *
+ *   Free Software Foundation, 51 Franklin Street, Suite 500, Boston,      *
+ *   MA 02110-1335, USA                                                    *
  ***************************************************************************/
 
 #ifndef SMB4KSAMBAOPTIONS_H
@@ -32,18 +32,24 @@
 #endif
 
 // Qt includes
-#include <QTreeWidget>
-#include <QTreeWidgetItem>
 #include <QList>
+#include <QEvent>
+#include <QCloseEvent>
+#include <QListWidgetItem>
+#include <QLabel>
+#include <QCheckBox>
 
 // KDE includes
 #include <ktabwidget.h>
 #include <kactionmenu.h>
 #include <kactioncollection.h>
+#include <klistwidget.h>
+#include <knuminput.h>
+#include <klineedit.h>
+#include <kcombobox.h>
 
-// forward declarations
-class Smb4KSambaOptionsInfo;
-
+// application specific includes
+#include <smb4kcustomoptions.h>
 
 /**
  * This class manages the configuration dialog of the options
@@ -59,6 +65,11 @@ class Smb4KSambaOptions : public KTabWidget
   Q_OBJECT
 
   public:
+    enum Tabs{ GeneralTab = 0,
+               MountingTab = 1,
+               ClientProgramsTab = 2,
+               CustomOptionsTab = 3 };
+
     /**
      * The constructor.
      *
@@ -73,26 +84,6 @@ class Smb4KSambaOptions : public KTabWidget
      */
     ~Smb4KSambaOptions();
 
-    /**
-     * This enumeration is used for the list view in the "Custom" tab.
-     */
-#ifndef __FreeBSD__
-    enum Columns{ ItemName = 0,
-                  Protocol = 1,
-                  WriteAccess = 2,
-                  Kerberos = 3,
-                  UID = 4,
-                  GID = 5,
-                  Port = 6 };
-#else
-    enum Columns{ ItemName = 0,
-                  Protocol = 1,
-                  Kerberos = 2,
-                  UID = 3,
-                  GID = 4,
-                  Port = 5 };
-#endif
-
     /**
      * This enumeration marks the type of the custom options item
      * in the tree widget.
@@ -106,7 +97,7 @@ class Smb4KSambaOptions : public KTabWidget
      *
      * @param list              The list with Smb4KSambaOptionsInfo objects
      */
-    void insertCustomOptions( const QList<Smb4KSambaOptionsInfo *> &list );
+    void insertCustomOptions( const QList<Smb4KCustomOptions *> &list );
 
     /**
      * This function returns the list of custom option items that are currently
@@ -114,28 +105,36 @@ class Smb4KSambaOptions : public KTabWidget
      *
      * @returns the list of custom option items.
      */
-    QList<Smb4KSambaOptionsInfo *> getCustomOptions();
-
-  signals:
+    const QList<Smb4KCustomOptions *> getCustomOptions();
+    
     /**
-     * This signal is emitted everytime the custom settings were modified by the
-     * user. When this signal is emitted, it does not necessarily mean that any
-     * custom setting changed. It only means that the user edited one option.
+     * Returns TRUE if there may be changed custom settings. You must check if
+     * this is indeed the case in you code.
+     * 
+     * @returns TRUE if custom settings may have changed.
      */
-    void customSettingsModified();
-
+    bool customSettingsMaybeChanged() { return m_maybe_changed; }
+    
   protected:
     /**
-     * Reimplemented from KTabWidget/QWidget. This function is used to close any edit
-     * widget in the list widget when the user pressed somewhere where no item is
-     * located.
-     *
-     * @param object              The object where the event occurred
-     *
-     * @param event               The event
+     * Reimplemented from QObject
      */
-    bool eventFilter( QObject *object,
+    bool eventFilter( QObject *obj,
                       QEvent *e );
+    
+  signals:
+    /**
+     * This signal is emitted everytime the custom settings potentially were 
+     * modified by the user. When this signal is emitted, it does not necessarily 
+     * mean that any custom setting changed. It only means that the user edited 
+     * one option.
+     */
+    void customSettingsModified();
+    
+    /**
+     * This signal is emitted when the settings should be reloaded.
+     */
+    void reloadCustomSettings();
 
   protected slots:
     /**
@@ -154,31 +153,11 @@ class Smb4KSambaOptions : public KTabWidget
 
     /**
      * This slot is invoked when an item is double clicked. It is used
-     * to edit the column where the user double clicked.
+     * to edit the item the user double clicked.
      *
      * @param item            The item that was double clicked.
-     *
-     * @param column          The column where the user double clicked the item
-     *                        @p item.
      */
-    void slotEditCustomItem( QTreeWidgetItem *item,
-                             int column );
-
-    /**
-     * This slot is invoked when the text of a custom entry in the tree
-     * widget was changed by choosing from a combo box.
-     *
-     * @param text            The new text for the protocol.
-     */
-    void slotCustomTextChanged( const QString &text );
-
-    /**
-     * This slot is invoked when an integer of a custom entry in the tree
-     * widget was changed.
-     *
-     * @param value           The new value
-     */
-    void slotCustomIntValueChanged( int value );
+    void slotEditCustomItem( QListWidgetItem *item );
 
     /**
      * This slot is invoked when the selection in the custom tree widget
@@ -195,38 +174,118 @@ class Smb4KSambaOptions : public KTabWidget
     void slotCustomContextMenuRequested( const QPoint &pos );
 
     /**
-     * This slot is connected to the context menu and is called when an
-     * action is activated.
-     *
-     * @param action          The action that was triggered.
+     * This slot is connected to the "Edit" action found in the context menu of
+     * the custom options tab. It is called when this action is triggered.
+     * 
+     * @param checked         TRUE if the action is checked and FALSE otherwise.
      */
-    void slotMenuActionTriggered( QAction * );
-
+    void slotEditActionTriggered( bool );
+    
+    /**
+     * This slot is connected to the "Remove" action found in the context menu
+     * of the custom options tab. It is called when this action is triggered.
+     *
+     * @param checked         TRUE if the action is checked and FALSE otherwise.
+     */
+    void slotRemoveActionTriggered( bool );
+    
+    /**
+     * This slot is connected to the "Clear List" action found in the context
+     * menu of the custom options tab. It is called when this action is triggered.
+     * 
+     * @param checked         TRUE if the action is checked and FALSE otherwise.
+     */
+    void slotClearActionTriggered( bool );
+    
+    /**
+     * This slot is connected to the "Undo" action found in the context
+     * menu of the custom options tab. It is called when this action is triggered.
+     * 
+     * @param checked         TRUE if the action is checked and FALSE otherwise.
+     */
+    void slotUndoActionTriggered( bool );
+    
+    /**
+     * This slot is called when a value was changed.
+     */
+    void slotEntryChanged();
+    
   private:
     /**
-     * The tree widget for the custom options
+     * Finds a custom options info in the private list. You need the @p url
+     * for this to work. 
+     * 
+     * @param url             The URL of the custom options info object
      */
-    QTreeWidget *m_custom_options;
+    Smb4KCustomOptions *findOptions( const QUrl &url );
+    
+    /**
+     * Populate the editors with the current settings and enable the
+     * widget.
+     */
+    void populateEditors( Smb4KCustomOptions *options );
+    
+    /**
+     * Clear the editors and disable the widget. 
+     */
+    void clearEditors();
+    
+    /**
+     * Commit changes 
+     */
+    void commitChanges();
+    
+    /**
+     * The list widget for the custom options
+     */
+    KListWidget *m_custom_options;
+    
+    /**
+     * The edit widgets
+     */
+    QWidget *m_editors;
+    
+    /**
+     * The UNC of the item
+     */
+    KLineEdit *m_unc_address;
+    
+    /**
+     * SMB Port
+     */
+    KIntNumInput *m_smb_port;
+
+#ifndef Q_OS_FREEBSD
+    /**
+     * Filesystem port
+     */
+    KIntNumInput *m_fs_port;
 
     /**
-     * The column that is currently edited.
+     * Write access
      */
-    int m_edit_column;
-
+    KComboBox *m_write_access;
+#endif
+    
     /**
-     * The current edit widget.
+     * Protocol hint
      */
-    QWidget *m_edit_widget;
-
+    KComboBox *m_protocol_hint;
+    
     /**
-     * The item that is currently edited.
+     * UID
      */
-    QTreeWidgetItem *m_edit_item;
-
+    KComboBox *m_user_id;
+    
     /**
-     * The value of the current KIntNumInput edit widget
+     * GID
      */
-    int m_edit_value;
+    KComboBox *m_group_id;
+    
+    /**
+     * Kerberos
+     */
+    QCheckBox *m_kerberos;
 
     /**
      * The action menu
@@ -237,6 +296,26 @@ class Smb4KSambaOptions : public KTabWidget
      * The action collection
      */
     KActionCollection *m_collection;
+    
+    /**
+     * The list of custom Samba options
+     */
+    QList<Smb4KCustomOptions *> m_options_list;
+    
+    /**
+     * The current custom options object
+     */
+    Smb4KCustomOptions m_current_options;
+    
+    /**
+     * Is it possible that the custom settings changed?
+     */
+    bool m_maybe_changed;
+    
+    /**
+     * List cleared or item removed?
+     */
+    bool m_removed;
 };
 
 #endif
