@@ -1158,6 +1158,7 @@ void Smb4KSharesViewPart::slotUnmountShare( bool /*checked*/ )
     case IconMode:
     {
       QList<QListWidgetItem *> selected_items = m_icon_view->selectedItems();
+      QList<Smb4KShare *> shares;
 
       for ( int i = 0; i < selected_items.size(); ++i )
       {
@@ -1165,7 +1166,7 @@ void Smb4KSharesViewPart::slotUnmountShare( bool /*checked*/ )
 
         if ( item )
         {
-          Smb4KMounter::self()->unmountShare( item->shareItem(), false, m_icon_view );
+          shares << item->shareItem();
         }
         else
         {
@@ -1173,11 +1174,14 @@ void Smb4KSharesViewPart::slotUnmountShare( bool /*checked*/ )
         }
       }
 
+      Smb4KMounter::self()->unmountShares( shares, false, m_icon_view );
+
       break;
     }
     case ListMode:
     {
       QList<QTreeWidgetItem *> selected_items = m_list_view->selectedItems();
+      QList<Smb4KShare *> shares;
 
       for ( int i = 0; i < selected_items.size(); ++i )
       {
@@ -1185,7 +1189,7 @@ void Smb4KSharesViewPart::slotUnmountShare( bool /*checked*/ )
 
         if ( item )
         {
-          Smb4KMounter::self()->unmountShare( item->shareItem(), false, m_list_view );
+          shares << item->shareItem();
         }
         else
         {
@@ -1193,6 +1197,8 @@ void Smb4KSharesViewPart::slotUnmountShare( bool /*checked*/ )
         }
       }
 
+      Smb4KMounter::self()->unmountShares( shares, false, m_list_view );
+
       break;
     }
     default:
